@@ -4,6 +4,7 @@ from gensim.models.word2vec import Word2Vec
 from karateclub.utils.diffuser import EulerianDiffuser
 from karateclub.estimator import Estimator
 
+
 class Diff2Vec(Estimator):
     r"""An implementation of `"Diff2Vec" <http://homepages.inf.ed.ac.uk/s1668259/papers/sequence.pdf>`_
     from the CompleNet '18 paper "Diff2Vec: Fast Sequence Based Embedding with Diffusion Graphs".
@@ -22,9 +23,19 @@ class Diff2Vec(Estimator):
         min_count (int): Minimal count of node occurrences. Default is 1.
         seed (int): Random seed value. Default is 42.
     """
-    def __init__(self, diffusion_number: int=10, diffusion_cover: int=80,
-                 dimensions: int=128, workers: int=4, window_size: int=5,
-                 epochs: int=1, learning_rate: float=0.05, min_count: int=1, seed: int=42):
+
+    def __init__(
+        self,
+        diffusion_number: int = 10,
+        diffusion_cover: int = 80,
+        dimensions: int = 128,
+        workers: int = 4,
+        window_size: int = 5,
+        epochs: int = 1,
+        learning_rate: float = 0.05,
+        min_count: int = 1,
+        seed: int = 42,
+    ):
 
         self.diffusion_number = diffusion_number
         self.diffusion_cover = diffusion_cover
@@ -48,20 +59,21 @@ class Diff2Vec(Estimator):
         diffuser = EulerianDiffuser(self.diffusion_number, self.diffusion_cover)
         diffuser.do_diffusions(graph)
 
-        model = Word2Vec(diffuser.diffusions,
-                         hs=1,
-                         alpha=self.learning_rate,
-                         epochs=self.epochs,
-                         vector_size=self.dimensions,
-                         window=self.window_size,
-                         min_count=self.min_count,
-                         workers=self.workers,
-                         seed=self.seed)
+        model = Word2Vec(
+            diffuser.diffusions,
+            hs=1,
+            alpha=self.learning_rate,
+            epochs=self.epochs,
+            vector_size=self.dimensions,
+            window=self.window_size,
+            min_count=self.min_count,
+            workers=self.workers,
+            seed=self.seed,
+        )
 
         num_of_nodes = graph.number_of_nodes()
         self._embedding = [model.wv[str(n)] for n in range(num_of_nodes)]
 
-
     def get_embedding(self) -> np.array:
         r"""Getting the node embedding.
 
