@@ -135,7 +135,7 @@ class Role2Vec(Estimator):
             seed=self.seed,
         )
 
-        self._embedding = [model.docvecs[str(i)] for i, _ in enumerate(documents)]
+        self._embedding = [model.dv[str(i)] for i, _ in enumerate(documents)]
 
     def get_embedding(self) -> np.array:
         r"""Getting the node embedding.
